==> nextcloud-25.0.8.tgz: nextcloud/apps/user_status/l10n/fr.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Statuts récents",
    "In a meeting" : "En réunion",
    "Commuting" : "Trajet",
    "Out sick" : "En congé de maladie",
    "Vacationing" : "En vacances",
    "Working remotely" : "Travail à distance",
    "In a call" : "En communication",
    "User status" : "Statut utilisateur",
    "View profile" : "Voir le profil",
    "Clear status after" : "Effacer l'état après",
    "Emoji for your status message" : "Emoji pour votre message de statut",
    "What is your status?" : "Quel est votre statut ?",
    "Predefined statuses" : "Statuts prédéfinis",
    "Previously set" : "Précédemment défini",
    "Reset status" : "Réinitialiser l'état",
    "Set status" : "Définir le statut",
    "Online status" : "Statut en ligne",
    "Status message" : "Message d'état",
    "Your status was set automatically" : "Votre état a été automatiquement défini",
    "Clear status message" : "Effacer le message d'état",
    "Set status message" : "Enregistrer le message d'état",
    "Reset status to \"{icon} {message}\"" : "Réinitialiser l'état en \"{icon} {message}\"",
    "Reset status to \"{message}\"" : "Réinitialiser l'état en \"{message}\"",
    "Reset status to \"{icon}\"" : "Réinitialiser l'état en \"{icon}\"",
    "There was an error saving the status" : "Une erreur s'est produite lors de l'enregistrement de l'état",
    "There was an error clearing the status" : "Une erreur s'est produite lors de l'effacement de l'état",
    "There was an error reverting the status" : "Une erreur est survenue dans le rétablissement d'état",
    "No recent status changes" : "Aucun changement de statut récent",
    "Away" : "Absent(e)",
    "Do not disturb" : "Ne pas déranger",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Ne pas effacer",
    "Today" : "Aujourd'hui",
    "This week" : "Cette semaine",
    "Online" : "En ligne",
    "Invisible" : "Invisible",
    "Offline" : "Hors-ligne",
    "There was an error saving the new status" : "Une erreur s'est produite lors de l'enregistrement du nouveau statut",
    "30 minutes" : "30 minutes",
    "1 hour" : "1 heure",
    "4 hours" : "4 heures",
    "Mute all notifications" : "Désactiver les notifications",
    "Appear offline" : "Apparaitre hors-ligne"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-25.0.11.tgz: nextcloud/apps/user_status/l10n/fr.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Statuts récents",
    "No recent status changes" : "Aucun changement de statut récent",
    "In a meeting" : "En réunion",
    "Commuting" : "Trajet",
    "Out sick" : "En congé de maladie",
    "Vacationing" : "En vacances",
    "Working remotely" : "Travail à distance",
    "In a call" : "En communication",
    "User status" : "Statut utilisateur",
    "View profile" : "Voir le profil",
    "Clear status after" : "Effacer l'état après",
    "Emoji for your status message" : "Emoji pour votre message de statut",
    "What is your status?" : "Quel est votre statut ?",
    "Predefined statuses" : "Statuts prédéfinis",
    "Previously set" : "Précédemment défini",
    "Reset status" : "Réinitialiser l'état",
    "Set status" : "Définir le statut",
    "Online status" : "Statut en ligne",
    "Status message" : "Message d'état",
    "Your status was set automatically" : "Votre état a été automatiquement défini",
    "Clear status message" : "Effacer le message d'état",
    "Set status message" : "Enregistrer le message d'état",
    "Reset status to \"{icon} {message}\"" : "Réinitialiser l'état en \"{icon} {message}\"",
    "Reset status to \"{message}\"" : "Réinitialiser l'état en \"{message}\"",
    "Reset status to \"{icon}\"" : "Réinitialiser l'état en \"{icon}\"",
    "There was an error saving the status" : "Une erreur s'est produite lors de l'enregistrement de l'état",
    "There was an error clearing the status" : "Une erreur s'est produite lors de l'effacement de l'état",
    "There was an error reverting the status" : "Une erreur est survenue dans le rétablissement d'état",
    "Don't clear" : "Ne pas effacer",
    "Today" : "Aujourd'hui",
    "This week" : "Cette semaine",
    "Online" : "En ligne",
    "Away" : "Absent(e)",
    "Do not disturb" : "Ne pas déranger",
    "Invisible" : "Invisible",
    "Offline" : "Hors-ligne",
    "There was an error saving the new status" : "Une erreur s'est produite lors de l'enregistrement du nouveau statut",
    "30 minutes" : "30 minutes",
    "1 hour" : "1 heure",
    "4 hours" : "4 heures",
    "Mute all notifications" : "Désactiver les notifications",
    "Appear offline" : "Apparaitre hors-ligne",
    "{status}, {timestamp}" : "{status}, {timestamp}"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
